@@ -4,10 +4,10 @@ use warnings;
 
 package Dist::Zilla::PluginBundle::MARCEL;
 BEGIN {
-  $Dist::Zilla::PluginBundle::MARCEL::VERSION = '1.100980';
+  $Dist::Zilla::PluginBundle::MARCEL::VERSION = '1.101520';
 }
 
-# ABSTRACT: build and release a distribution like me
+# ABSTRACT: Build and release a distribution like MARCEL
 use Class::MOP;
 use Moose;
 use Moose::Autobox;
@@ -155,9 +155,6 @@ sub bundle_config {
         [ CheckChangeLog => {} ],
 
         #[ @Git],
-        [ 'Git::Check'  => {} ],
-        [ 'Git::Commit' => {} ],
-        [ 'Git::Tag'    => {} ],
         [ UploadToCPAN  => {} ],
     );
 
@@ -171,12 +168,12 @@ sub bundle_config {
     }
 
     # add git plugins
-    # my @gitplugins = Dist::Zilla::PluginBundle::Git->bundle_config(
-    #     {   name    => "$section->{name}/Git",
-    #         payload => {},
-    #     }
-    # );
-    # push @plugins, @gitplugins;
+    my @gitplugins = Dist::Zilla::PluginBundle::Git->bundle_config(
+        {   name    => "$section->{name}/Git",
+            payload => {},
+        }
+    );
+    push @plugins, @gitplugins;
 
     return @plugins;
 }
@@ -195,11 +192,11 @@ __END__
 
 =head1 NAME
 
-Dist::Zilla::PluginBundle::MARCEL - build and release a distribution like me
+Dist::Zilla::PluginBundle::MARCEL - Build and release a distribution like MARCEL
 
 =head1 VERSION
 
-version 1.100980
+version 1.101520
 
 =head1 SYNOPSIS
 
@@ -270,9 +267,7 @@ equivalent to:
 
     ; -- release
     [CheckChangeLog]
-    [Git::Check]
-    [Git::Commit]
-    [Git::Tag]
+    [@Git]
     [UploadToCPAN]
 
 The following options are accepted:
@@ -311,7 +306,7 @@ See perlmodinstall for information and options on installing Perl modules.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-PluginBundle-MARCEL>.
+L<http://rt.cpan.org>.
 
 =head1 AVAILABILITY
 
@@ -320,6 +315,11 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Dist-Zilla-PluginBundle-MARCEL/>.
 
+The development version lives at
+L<http://github.com/hanekomu/Dist-Zilla-PluginBundle-MARCEL/>.
+Instead of sending patches, please fork this project using the standard git
+and github infrastructure.
+
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
